/*@flow*/
/**
 *  Copyright (c) 2015, Facebook, Inc.
 *  All rights reserved.
 *
 *  This source code is licensed under the BSD-style license found in the
 *  LICENSE file in the root directory of this source tree. An additional grant
 *  of patent rights can be found in the PATENTS file in the same directory.
 */

'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});
var introspectionQuery = '\n  query IntrospectionQuery {\n    __schema {\n      queryType { name }\n      mutationType { name }\n      types {\n        ...FullType\n      }\n      directives {\n        name\n        description\n        args {\n          ...InputValue\n        }\n        onOperation\n        onFragment\n        onField\n      }\n    }\n  }\n\n  fragment FullType on __Type {\n    kind\n    name\n    description\n    fields {\n      name\n      description\n      args {\n        ...InputValue\n      }\n      type {\n        ...TypeRef\n      }\n      isDeprecated\n      deprecationReason\n    }\n    inputFields {\n      ...InputValue\n    }\n    interfaces {\n      ...TypeRef\n    }\n    enumValues {\n      name\n      description\n      isDeprecated\n      deprecationReason\n    }\n    possibleTypes {\n      ...TypeRef\n    }\n  }\n\n  fragment InputValue on __InputValue {\n    name\n    description\n    type { ...TypeRef }\n    defaultValue\n  }\n\n  fragment TypeRef on __Type {\n    kind\n    name\n    ofType {\n      kind\n      name\n      ofType {\n        kind\n        name\n        ofType {\n          kind\n          name\n        }\n      }\n    }\n  }\n';

exports.introspectionQuery = introspectionQuery;

/*:: export type IntrospectionQuery = {
  __schema: IntrospectionSchema
}*/
/*:: export type IntrospectionSchema = {
  queryType: IntrospectionNamedTypeRef;
  mutationType: ?IntrospectionNamedTypeRef;
  types: Array<IntrospectionType>;
  directives: Array<IntrospectionDirective>;
}*/
/*:: export type IntrospectionType =
  IntrospectionScalarType |
  IntrospectionObjectType |
  IntrospectionInterfaceType |
  IntrospectionUnionType |
  IntrospectionEnumType |
  IntrospectionInputObjectType*/
/*:: export type IntrospectionScalarType = {
  kind: 'SCALAR';
  name: string;
  description: ?string;
}*/
/*:: export type IntrospectionObjectType = {
  kind: 'OBJECT';
  name: string;
  description: ?string;
  fields: Array<IntrospectionField>;
  interfaces: Array<IntrospectionNamedTypeRef>;
}*/
/*:: export type IntrospectionInterfaceType = {
  kind: 'INTERFACE';
  name: string;
  description: ?string;
  fields: Array<IntrospectionField>;
  possibleTypes: Array<IntrospectionNamedTypeRef>;
}*/
/*:: export type IntrospectionUnionType = {
  kind: 'UNION';
  name: string;
  description: ?string;
  possibleTypes: Array<IntrospectionNamedTypeRef>;
}*/
/*:: export type IntrospectionEnumType = {
  kind: 'ENUM';
  name: string;
  description: ?string;
  enumValues: Array<IntrospectionEnumValue>;
}*/
/*:: export type IntrospectionInputObjectType = {
  kind: 'INPUT_OBJECT';
  name: string;
  description: ?string;
  inputFields: Array<IntrospectionInputValue>;
}*/
/*:: export type IntrospectionTypeRef =
  IntrospectionNamedTypeRef |
  IntrospectionListTypeRef |
  IntrospectionNonNullTypeRef*/
/*:: export type IntrospectionNamedTypeRef = {
  kind: string;
  name: string;
}*/
/*:: export type IntrospectionListTypeRef = {
  kind: 'LIST';
  ofType?: IntrospectionTypeRef;
}*/
/*:: export type IntrospectionNonNullTypeRef = {
  kind: 'NON_NULL';
  ofType?: IntrospectionTypeRef;
}*/
/*:: export type IntrospectionField = {
  name: string;
  description: ?string;
  args: Array<IntrospectionInputValue>;
  type: IntrospectionTypeRef;
  isDeprecated: boolean;
  deprecationReason: ?string;
}*/
/*:: export type IntrospectionInputValue = {
  name: string;
  description: ?string;
  type: IntrospectionTypeRef;
  defaultValue: ?string;
}*/
/*:: export type IntrospectionEnumValue = {
  name: string;
  description: ?string;
  isDeprecated: boolean;
  deprecationReason: ?string;
}*/
/*:: export type IntrospectionDirective = {
  name: string;
  description: ?string;
  args: Array<IntrospectionInputValue>;
  onOperation: boolean;
  onFragment: boolean;
  onField: boolean;
}*/